@@ -5,6 +5,7 @@ from typing import Dict, Optional
 import requests
 from notecoin.okex.common import exceptions
 from notecoin.okex.v5 import utils
+from notecoin.okex.v5.types import Response
 
 GET = "GET"
 POST = "POST"
@@ -90,9 +91,9 @@ class BaseClient(object):
                 except Exception as e:
                     logging.warning(f"error:{e}")
                     pass
-                return response.json(), r
+                return Response(response.json()), r
             else:
-                return response.json()
+                return Response(response.json())
 
         except ValueError:
             raise exceptions.OkexRequestException('Invalid Response: %s' % response.text)
