@@ -1,7 +1,7 @@
 from typing import Optional
 
 from notecoin.okex.v5.client.base import BaseClient
-from notecoin.okex.v5.consts import *
+from notecoin.okex.v5.consts import GET
 
 
 class SystemClient(BaseClient):
@@ -10,10 +10,8 @@ class SystemClient(BaseClient):
         super(SystemClient, self).__init__(*args, **kwargs)
 
     def status(self, state: Optional[str] = None):
-        params = {}
-        if state is not None:
-            params['state'] = state
-
-        data = self._request_with_params(GET, INSTRUMENTS, params)["data"]
-
+        uri = '/api/v5/system/status'
+        params = {'state': state}
+        data = self._request_with_params(GET, uri, params)
         return data
+
